@@ -30,7 +30,8 @@ def get_run_params(task):
     'artifact_bucket_private': os.environ.get('ARTIFACT_S3FILE_BUCKET_PRIVATE'),
     'artifact_prefix_private': os.environ.get('ARTIFACT_S3FILE_PREFIX_PRIVATE'),
     'artifact_endpoint_private': os.environ.get('ARTIFACT_S3FILE_ENDPOINT_PRIVATE'),
-    'command_endpoint': os.environ.get('COMMAND_ENDPOINT')
+    'command_endpoint': os.environ.get('COMMAND_ENDPOINT'),
+    'fileinfo_endpoint': os.environ.get('FILEINFO_ENDPOINT')
   }
 
   return params
@@ -69,7 +70,7 @@ def task_worker(task):
 
 if __name__ == '__main__':
   healtcheck_worker()
-  
+
   while True:
     task = poll_task()
     if task:
